// Copyright 2019 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     https://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

'use strict';

const {assert} = require('chai');
const {describe, it, after} = require('mocha');
const cp = require('child_process');
const {v4} = require('uuid');

const region = 'us-central1';
const clusterName = `node-cc-test-${v4()}`;

const dataproc = require('@google-cloud/dataproc');
const clusterClient = new dataproc.v1.ClusterControllerClient({
  apiEndpoint: `${region}-dataproc.googleapis.com`,
});

const projectId = process.env.GCLOUD_PROJECT;

const execSync = cmd =>
  cp.execSync(cmd, {
    encoding: 'utf-8',
  });

describe('create a dataproc cluster', () => {
  it('should create a dataproc cluster', async () => {
    const stdout = execSync(
      `node createCluster.js "${projectId}" "${region}" "${clusterName}"`
    );
    assert.match(stdout, new RegExp(`${clusterName}`));
  });

  after(async () => {
    await clusterClient.deleteCluster({
      projectId: projectId,
      region: region,
      clusterName: clusterName,
    });
  });
});
